@@ -23,6 +23,7 @@ from .literals import (
     ReactionType,
     RecommendationCategoryType,
     RepositoryAssociationStateType,
+    SeverityType,
     TypeType,
     VendorNameType,
 )
@@ -79,6 +80,7 @@ __all__ = (
     "RepositoryTypeDef",
     "RequestMetadataTypeDef",
     "ResponseMetadataTypeDef",
+    "RuleMetadataTypeDef",
     "S3BucketRepositoryTypeDef",
     "S3RepositoryDetailsTypeDef",
     "S3RepositoryTypeDef",
@@ -559,6 +561,8 @@ RecommendationSummaryTypeDef = TypedDict(
         "EndLine": int,
         "Description": str,
         "RecommendationCategory": RecommendationCategoryType,
+        "RuleMetadata": "RuleMetadataTypeDef",
+        "Severity": SeverityType,
     },
     total=False,
 )
@@ -646,6 +650,18 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+RuleMetadataTypeDef = TypedDict(
+    "RuleMetadataTypeDef",
+    {
+        "RuleId": str,
+        "RuleName": str,
+        "ShortDescription": str,
+        "LongDescription": str,
+        "RuleTags": List[str],
+    },
+    total=False,
+)
+
 _RequiredS3BucketRepositoryTypeDef = TypedDict(
     "_RequiredS3BucketRepositoryTypeDef",
     {
